@@ -6,7 +6,7 @@ use Mouse ();
 use Mouse::Exporter;
 use Mouse::Util::MetaRole;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 Mouse::Exporter->setup_import_methods( also => 'Mouse' );
 
@@ -80,12 +80,15 @@ Same as above except allows multiple method declaration:
       bar2 => sub { 'bar2' },
   );
 
+=head1 SEE ALSO
+
+L<Mouse>
+L<MooseX::SingletonMethod>
+
 =head1 AUTHOR
 
 Hideaki Ohno E<lt>hide.o.j55 {at} gmail.comE<gt>
 
-=head1 SEE ALSO
-
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
